@@ -1,8 +1,8 @@
 #include <stdint.h>
 
 typedef struct {
-  uint16_t   vendorid;
-  uint16_t   deviceid;
+  WORD_t   vendorid;
+  WORD_t   deviceid;
   int        chipreg;
   const char *name;
 } AthlonChips_s;
@@ -10,7 +10,7 @@ typedef struct {
 typedef struct {
   const char *desc;
   int        addr;
-  uint32_t   bit;
+  LONG_t   bit;
 } EachReg_s;
 
 typedef struct {
@@ -54,10 +54,10 @@ static AthlonChips_s AthlonChips[] = {
   /* VIA VT8366 */
   { VENDORID_VIA, 0x3099, REGID_VIA_KT266, "VIA KT266/333[A]" },
   /* VIA VT8375 */
-  { VENDORID_VIA, 0x3116, REGID_VIA_KT266, "VIA KM266" },
-  { VENDORID_VIA, 0x3156, REGID_VIA_KT266, "VIA P/KN266" },
+  { VENDORID_VIA, 0x3116, REGID_VIA_KT266, "VIA KM266[A]/KL266/KM333" },
+  { VENDORID_VIA, 0x3156, REGID_VIA_KT266, "VIA KN266" },
   /* VIA VT8368 */
-  { VENDORID_VIA, 0x3189, REGID_VIA_KT400, "VIA KT400[A]" },
+  { VENDORID_VIA, 0x3189, REGID_VIA_KT400, "VIA KT400[A]/KT600" },
   /* VIA VT8378 */
   { VENDORID_VIA, 0x3205, REGID_VIA_KT400, "VIA KM400[A]" },
   /* VIA KT880 (function 2) */
@@ -86,50 +86,72 @@ static AthlonChips_s AthlonChips[] = {
 
 static ChipReg_s ChipReg[] = {
   /* AMD chipset ----------------------------------------------------------*/
+#if 0 /* use WORD instead of LONG (0.3.10) */
   /* AMD AMD-751/761 */
-  { REGID_AMD_751, LONG,
+  { REGID_AMD_751, TP_LONG,
     { {"Halt Disconnect and Stop Grant Disconnect", 0x60, 0x00060000},
       {NULL, 0, 0 } } },
-  /* AMD AMD-762 (Chipset has not support HALT disconnect,
-     so Powersaving only enables when S1 or S3 state entered */
-  { REGID_AMD_762, LONG, { {"Stop Grant Disconnect #0", 0x60, 0x00020000},
-		  {"Stop Grant Disconnect #1", 0x68, 0x00020000},
-		  {NULL, 0, 0 } } },
+  /* AMD AMD-762 */
+  { REGID_AMD_762, TP_LONG,
+    { {"Halt Disconnect and Stop Grant Disconnect #0", 0x60, 0x00060000},
+      {"Halt Disconnect and Stop Grant Disconnect #1", 0x68, 0x00060000},
+      {NULL, 0, 0 } } },
+#else
+  /* AMD AMD-751/761 */
+  { REGID_AMD_751, TP_WORD,
+    { {"Halt Disconnect and Stop Grant Disconnect", 0x62, 0x0006},
+      {NULL, 0, 0 } } },
+  /* AMD AMD-762 */
+  { REGID_AMD_762, TP_WORD,
+    { {"Halt Disconnect and Stop Grant Disconnect #0", 0x62, 0x0006},
+      {"Halt Disconnect and Stop Grant Disconnect #1", 0x6a, 0x0006},
+      {NULL, 0, 0 } } },
+#endif
+
   /* VIA Chipset ---------------------------------------------------------*/
   /* VIA KX/KLE/KT/KM/KL/KN133[A] */
-  { REGID_VIA_KT133, BYTE, { {"Disconnect when STPGNT Detected", 0x52, 0x80},
-		  {NULL, 0, 0 } } },
+  { REGID_VIA_KT133, TP_BYTE, 
+    { {"Disconnect when STPGNT Detected", 0x52, 0x80},
+      {NULL, 0, 0 } } },
   /* VIA KT/KM/266/333[A] */
-  { REGID_VIA_KT266, BYTE, { {"Disconnect when STPGNT Detected", 0x92, 0x80},
-		  {"HALT Command Detection", 0x95, 0x02},
-		  {NULL, 0, 0 } } },
+  { REGID_VIA_KT266, TP_BYTE, 
+    { {"Disconnect when STPGNT Detected", 0x92, 0x80},
+      {"HALT Command Detection", 0x95, 0x02},
+      {NULL, 0, 0 } } },
    /* VIA VT8368 */
-  { REGID_VIA_KT400, BYTE, { {"Disconnect when STPGNT Detected", 0xD2, 0x80},
-		  {"HALT Command Detection", 0xD5, 0x02},
-		  {NULL, 0, 0 } } },
+  { REGID_VIA_KT400, TP_BYTE, 
+    { {"Disconnect when STPGNT Detected", 0xD2, 0x80},
+      {"HALT Command Detection", 0xD5, 0x02},
+      {NULL, 0, 0 } } },
    /* VIA KT880 */
-  { REGID_VIA_KT880, BYTE, { {"Disconnect when STPGNT Detected", 0x82, 0x80},
-		  {"HALT Command Detection", 0x85, 0x02},
-		  {NULL, 0, 0 } } }, 
+  { REGID_VIA_KT880, TP_BYTE, 
+    { {"Disconnect when STPGNT Detected", 0x82, 0x80},
+      {"HALT Command Detection", 0x85, 0x02},
+      {NULL, 0, 0 } } }, 
   /* SiS Chipset ---------------------------------------------------------*/
   /* SiS 730/733 */
-  { REGID_SIS_730, BYTE, { {"ACPI C1 Disconnect Enable", 0x6B, 0x01},
-		  {NULL, 0, 0 } } },
+  { REGID_SIS_730, TP_BYTE, 
+    { {"ACPI C1 Disconnect Enable", 0x6B, 0x01},
+      {NULL, 0, 0 } } },
   /* SiS 735/740/745/755 */
-  { REGID_SIS_735, SHORT, { {"ACPI C1 Disconnect Enable", 0x6A, 0x0001},
-		   {NULL, 0, 0 } } },
+  { REGID_SIS_735, TP_WORD, 
+    { {"ACPI C1 Disconnect Enable", 0x6A, 0x0001},
+      {NULL, 0, 0 } } },
   /* SiS 746 or later */
-  { REGID_SIS_746, SHORT, { {"ACPI C1 Disconnect Enable", 0x6C, 0x0001},
-		   {NULL, 0, 0 } } },
+  { REGID_SIS_746, TP_WORD, 
+    { {"ACPI C1 Disconnect Enable", 0x6C, 0x0001},
+      {NULL, 0, 0 } } },
   /* nVIDIA chipset -----------------------------------------------------*/
   /* nForce */
-  { REGID_NVIDIA_NFORCE1, SHORT, { /* {"Self-reflesh enable", 0x6C, 0x8000}, */
-		  {"Halt Disconnect and Stop Grant Disconnect",
-		   0xE6, 0x0600 },
-		  {NULL, 0, 0 } } },
+  { REGID_NVIDIA_NFORCE1, TP_WORD, 
+    { /* {"Self-reflesh enable", 0x6C, 0x8000}, */
+      {"Halt Disconnect and Stop Grant Disconnect",
+       0xE6, 0x0600 },
+      {NULL, 0, 0 } } },
   /* nForce2 */
-  { REGID_NVIDIA_NFORCE2, BYTE, { {"Halt Disconnect and Stop Grant Disconnect", 0x6F, 0x10}, 
-		  {NULL, 0, 0 } } },
+  { REGID_NVIDIA_NFORCE2, TP_BYTE, 
+    { {"Halt Disconnect and Stop Grant Disconnect", 0x6F, 0x10}, 
+      {NULL, 0, 0 } } },
   /* end mark */
   { 0, 0, { {NULL, 0, 0} } }
 };
